@@ -31,11 +31,12 @@
 
 #include <ksharedconfig.h>
 
-#include <diffmodel.h>
-#include <diffhunk.h>
-#include <difference.h>
+#include <libkomparediff2/diffmodel.h>
+#include <libkomparediff2/diffhunk.h>
+#include <libkomparediff2/difference.h>
+#include <libkomparediff2/komparemodellist.h>
+
 #include "viewsettings.h"
-#include <komparemodellist.h>
 #include "komparesplitter.h"
 
 #define COL_LINE_NO      0
@@ -523,7 +524,7 @@ KompareListViewItemDelegate::~KompareListViewItemDelegate()
 void KompareListViewItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const
 {
 	int column = index.column();
-	QStyleOptionViewItemV4 changedOption = option;
+	QStyleOptionViewItem changedOption = option;
 	if( column == COL_LINE_NO )
 		changedOption.displayAlignment = Qt::AlignRight;
 	KompareListViewItem* item = static_cast<KompareListViewItem*>( static_cast<KompareListView*>( parent() )->itemFromIndex( index ) );
@@ -617,7 +618,7 @@ void KompareListViewItem::paintCell( QPainter* p, const QStyleOptionViewItem& op
 	// We have to paint the item which shines through or we'll end up with glitches.
 	KompareListViewItem* nextItem = (KompareListViewItem*)kompareListView()->itemBelow(this);
 	if( nextItem ) {
-		QStyleOptionViewItemV4 changedOption = option;
+		QStyleOptionViewItem changedOption = option;
 		changedOption.rect.translate( 0, height() );
 		nextItem->paintCell( p, changedOption, column );
 	}
@@ -971,5 +972,3 @@ void KompareListViewHunkItem::paintCell( QPainter* p, const QStyleOptionViewItem
 	}
 	}
 }
-
-#include "komparelistview.moc"
